@@ -16,11 +16,13 @@ use {
     futures_util::stream::StreamExt,
     hyper::server::accept,
     hyper::server::conn::AddrIncoming,
-    rustls::{Certificate, PrivateKey, ServerConfig},
     std::fs::File,
     std::future::ready,
     std::path::Path,
+    std::sync::Arc,
     tls_listener::TlsListener,
+    tokio_rustls::rustls::{Certificate, PrivateKey, ServerConfig},
+    tokio_rustls::TlsAcceptor,
 };
 
 use drive::{AliyunDrive, DriveConfig};
@@ -40,8 +42,13 @@ struct Opt {
     #[clap(short, env = "PORT", long, default_value = "8080")]
     port: u16,
     /// Aliyun drive refresh token
-    #[clap(short, long, env = "REFRESH_TOKEN")]
-    refresh_token: String,
+    #[clap(
+        short,
+        long,
+        env = "REFRESH_TOKEN",
+        required_unless_present = "workdir"
+    )]
+    refresh_token: Option<String>,
     /// WebDAV authentication username
     #[clap(short = 'U', long, env = "WEBDAV_AUTH_USER")]
     auth_user: Option<String>,
@@ -83,6 +90,9 @@ struct Opt {
     #[cfg(feature = "rustls-tls")]
     #[clap(long, env = "TLS_KEY")]
     tls_key: Option<PathBuf>,
+    /// Enable debug log
+    #[clap(long)]
+    debug: bool,
 }
 
 #[tokio::main(flavor = "multi_thread")]
@@ -90,12 +100,16 @@ async fn main() -> anyhow::Result<()> {
     #[cfg(feature = "native-tls-vendored")]
     openssl_probe::init_ssl_cert_env_vars();
 
+    let opt = Opt::parse();
     if env::var("RUST_LOG").is_err() {
-        env::set_var("RUST_LOG", "aliyundrive_webdav=info");
+        if opt.debug {
+            env::set_var("RUST_LOG", "aliyundrive_webdav=debug");
+        } else {
+            env::set_var("RUST_LOG", "aliyundrive_webdav=info");
+        }
     }
     tracing_subscriber::fmt::init();
 
-    let opt = Opt::parse();
     let auth_user = opt.auth_user;
     let auth_password = opt.auth_password;
     if (auth_user.is_some() && auth_password.is_none())
@@ -135,11 +149,7 @@ async fn main() -> anyhow::Result<()> {
             opt.no_trash,
         )
     };
-    let drive = AliyunDrive::new(drive_config, opt.refresh_token)
-        .await
-        .map_err(|_| {
-            io::Error::new(io::ErrorKind::Other, "initialize aliyundrive client failed")
-        })?;
+    let drive = AliyunDrive::new(drive_config, opt.refresh_token.unwrap_or_default()).await?;
     let fs = AliyunDriveFileSystem::new(
         drive,
         opt.root,
@@ -148,13 +158,7 @@ async fn main() -> anyhow::Result<()> {
         no_trash,
         opt.read_only,
     )
-    .await
-    .map_err(|_| {
-        io::Error::new(
-            io::ErrorKind::Other,
-            "initialize aliyundrive file system failed",
-        )
-    })?;
+    .await?;
     debug!("aliyundrive file system initialized");
 
     let dav_server = DavHandler::builder()
@@ -179,18 +183,17 @@ async fn main() -> anyhow::Result<()> {
     if use_tls {
         let tls_key = opt.tls_key.as_ref().unwrap();
         let tls_cert = opt.tls_cert.as_ref().unwrap();
-        let incoming = TlsListener::new(
-            rustls_server_config(tls_key, tls_cert)?,
-            AddrIncoming::bind(&addr)?,
-        )
-        .filter(|conn| {
-            if let Err(err) = conn {
-                error!("TLS error: {:?}", err);
-                ready(false)
-            } else {
-                ready(true)
-            }
-        });
+        let incoming =
+            TlsListener::new(tls_acceptor(tls_key, tls_cert)?, AddrIncoming::bind(&addr)?).filter(
+                |conn| {
+                    if let Err(err) = conn {
+                        error!("TLS error: {:?}", err);
+                        ready(false)
+                    } else {
+                        ready(true)
+                    }
+                },
+            );
         let server = hyper::Server::builder(accept::from_stream(incoming)).serve(MakeSvc {
             auth_user: auth_user.clone(),
             auth_password: auth_password.clone(),
@@ -293,7 +296,7 @@ impl<T> Service<T> for MakeSvc {
 }
 
 #[cfg(feature = "rustls-tls")]
-fn rustls_server_config(key: &Path, cert: &Path) -> anyhow::Result<ServerConfig> {
+fn tls_acceptor(key: &Path, cert: &Path) -> anyhow::Result<TlsAcceptor> {
     let mut key_reader = io::BufReader::new(File::open(key)?);
     let mut cert_reader = io::BufReader::new(File::open(cert)?);
 
@@ -310,7 +313,7 @@ fn rustls_server_config(key: &Path, cert: &Path) -> anyhow::Result<ServerConfig>
 
     config.alpn_protocols = vec![b"h2".to_vec(), b"http/1.1".to_vec()];
 
-    Ok(config)
+    Ok(Arc::new(config).into())
 }
 
 #[cfg(feature = "rustls-tls")]
